@@ -14,7 +14,7 @@ has 'backend';
 has remove_after => 864000;
 has tasks => sub { {} };
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 sub add_task {
   my ($self, $name, $cb) = @_;
@@ -167,7 +167,7 @@ following new ones.
     ...
   });
 
-Emitted when a new worker is created.
+Emitted in the worker process after it has been created.
 
   $minion->on(worker => sub {
     my ($minion, $worker) = @_;
@@ -254,6 +254,12 @@ Job priority, defaults to C<0>.
 Get L<Minion::Job> object without making any changes to the actual job or
 return C<undef> if job does not exist.
 
+  # Check job state
+  my $state = $minion->job($id)->info->{state};
+
+  # Get job result
+  my $result = $minion->job($id)->info->{result};
+
 =head2 new
 
   my $minion = Minion->new(File => '/Users/sri/minion.db');
